.. opty documentation master file, created by
   sphinx-quickstart on Thu Jun  1 08:16:55 2017.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to opty's documentation!
================================

Contents
--------

.. toctree::
   :maxdepth: 2

   theory
   examples/index.rst
   api
   references

.. include:: ../README.rst

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
